@@ -34,11 +34,20 @@
 #define GTK_DISABLE_DEPRECATED
 #define GNOME_DISABLE_DEPRECATED
 
+#define MINIMUM_WINDOW_WIDTH   422
+#define MINIMUM_WINDOW_HEIGHT  310
+#define GNOME_SEARCH_TOOL_ICON  "gnome-searchtool.png"
+
 #ifdef __cplusplus
 extern "C" {
 #pragma }
 #endif
 
+#include <gconf/gconf.h>
+#include <gconf/gconf-client.h>
+
+GConfClient * global_gconf_client;
+
 typedef enum {
 	SEARCH_CONSTRAINT_END, 
 	SEARCH_CONSTRAINT_BOOL, 
@@ -71,12 +80,14 @@ typedef enum {
 struct _SearchStruct {
 	gint			pid;
 	gint 	        	timeout;
+	gint			animation_timeout;
 	gchar			*look_in_folder;
 	gchar           	*file_is_named_pattern;
 	gchar 	  		*regex_string;
 	gboolean		lock;	
 	gboolean		show_hidden_files;
 	gboolean		regex_matching_enabled;
+	gboolean		not_running_timeout;
 	RunStatus        	running;
 } search_command;
 
@@ -87,14 +98,16 @@ struct _InterfaceStruct {
 	GtkWidget		*stop_button;
 	GtkWidget 		*save_button;
 	GtkWidget 		*main_window;	
+	GtkWidget		*drawing_area;
+	GdkPixbuf		*pixbuf;	
+	GtkWidget		*table;	
 	GtkWidget 		*file_selector;
-	GtkWidget 		*status_bar;
-	GtkWidget   		*progress_bar;
-	GtkWidget	 	*disclosure;
+	GtkWidget		*checkbutton;
 	GtkWidget		*add_button;
 	GtkWidget 		*additional_constraints;
 	GtkWidget		*constraint_menu;
 	GtkWidget 		*constraint;
+	GtkWidget		*results_label;
 	GtkWidget       	*results;
 	GtkWidget        	*tree;
 	GtkListStore     	*model;	
@@ -105,6 +118,7 @@ struct _InterfaceStruct {
 	GList 			*selected_constraints;
 	gchar 		 	*save_results_file;	
 	gint 		  	selected_constraint;
+	gint			current_animation_frame;
 	GnomeIconTheme	 	*icon_theme;
 	gboolean  	  	is_gail_loaded;
 } interface;
@@ -127,7 +141,8 @@ spawn_search_command 		(gchar *command);
 
 void  		
 add_constraint 			(gint constraint_id,
-				 gchar *value);
+				 gchar *value,
+				 gboolean show_constraint);
 
 void  		
 remove_constraint 		(gint constraint_id);
@@ -138,9 +153,23 @@ update_constraint_info 		(SearchConstraint *constraint,
 void
 set_constraint_selected_state	(gint		constraint_id, 
 				 gboolean	state);
+void
+set_constraint_gconf_boolean 	(gint 		constraint_id, 
+				 gboolean 	flag);
 gboolean
 update_progress_bar 		(gpointer data);
 
+gboolean
+update_animation_timeout_cb 	(gpointer data);
+
+void
+set_clone_command		(gint *argcp,
+				 gchar ***argvp,
+				 gpointer client_data,
+				 gboolean escape_values);
+gchar *
+get_desktop_item_name 		(void);
+
 #ifdef __cplusplus
 }
 #endif
